@@ -53,6 +53,12 @@ class NVE(lammps_step.Energy):
 
         timestep, P['timestep'] = self.timestep(P['timestep'])
 
+        if extras is not None and 'nsteps' in extras:
+            nsteps = extras['nsteps']
+        else:
+            time = P['time'].to('fs').magnitude
+            nsteps = round(time / timestep)
+
         # Have to fix formatting for printing...
         PP = dict(P)
         for key in PP:
@@ -63,8 +69,8 @@ class NVE(lammps_step.Energy):
             __(self.description_text(), **PP, indent=7 * ' ')
         )
 
-        time = lammps_step.to_lammps_units(P['time'], quantity='time')
-        nsteps = round(time / timestep)
+        # time = lammps_step.to_lammps_units(P['time'], quantity='time')
+        # nsteps = round(time / timestep)
 
         thermo_properties = (
             'time temp press etotal ke pe ebond '
@@ -92,7 +98,7 @@ class NVE(lammps_step.Energy):
         nfixes += 1
         lines.append(
             'fix                 {} '.format(nfixes) + 'all  ave/time '
-            '{} {} {} {} file summary_nve_{}.txt'.format(
+            '{} {} {} {} file summary_nve_{}_iter_0.txt'.format(
                 nevery, nrepeat, nfreq, properties,
                 '_'.join(str(e) for e in self._id)
             )
@@ -123,7 +129,8 @@ class NVE(lammps_step.Energy):
             lines.append(
                 (
                     "fix                 {} all ave/time {} {} {} {} off 2 "
-                    "title1 '{}' title2 '{}' file trajectory_nve_{}.seamm_trj"
+                    "title1 '{}' title2 '{}' file "
+                    "trajectory_nve_{}_iter_0.seamm_trj"
                 ).format(
                     nfixes, nevery, nrepeat, nfreq, properties, title1, title2,
                     '_'.join(str(e) for e in self._id)
